# -*- coding: utf-8 -*-

"""
    Django-flash
    ~~~~~~~~~~~~

    Rails-like *flash* messages support for Django.


    :copyright: 2008-2009, Destaquenet Technology Solutions.
    :license: BSD.
"""

__version__ = '1.5'

